@@ -29,9 +29,11 @@ ATTR_TYPES = {
     'number': ('n', 'int'),
     'room_count': ('rc', 'int'),
     'square': ('sq', 'float'),
+    'square_out': ('sqo', 'float'),
     'status': ('st', 'int'),
     'total_cost': ('tc', 'int'),
     'cost_per_meter': ('cpm', 'int'),
+    'pl': ('pl', 'int'),
     'type': ('t', 'unicode'),
     'note': ('nt', 'unicode')
 }
@@ -539,11 +541,11 @@ class Apartment(Entity, Mapping):
     def render_outline(self, source_dir, node_name=None, bound_box=False,
                        reverse=False, find_by_shorthand=False, attribs=None,
                        style_attribs=True, skip_count_check=False,
-                       siblings=None):
+                       siblings=None, ext=None):
         """Render apartment outline svg file with style attributes"""
 
         svg_ = None
-        svg_path = self.pick_file(source_dir)
+        svg_path = self.pick_file(source_dir, ext=ext)
         poly_nodes = get_polygon_nodes(svg_path,
                                        skip_count_check=skip_count_check)
         if not poly_nodes:
